@@ -1,4 +1,4 @@
-"""djLint function to call jsbeautify."""
+"""djLint function to call jsbeautifier."""
 from functools import partial
 
 import jsbeautifier
