@@ -86,7 +86,7 @@ def find_djlintrc(root: Path) -> Optional[Path]:
 
 
 def find_djlint_rules(root: Path) -> Optional[Path]:
-    """Search upstream for a pyprojec.toml file."""
+    """Search upstream for a pyproject.toml file."""
 
     rules = root / ".djlint_rules.yaml"
 
@@ -355,8 +355,8 @@ class Config:
             | <\?php
             | <script
             | <!--
-            | [^\{]{\#(?!\s*djlint\:\s*on)
-            | ^{\#(?!\s*djlint\:\s*on)
+            | [^\{]{\#(?!\s*djlint\:\s*(?:on|off))
+            | ^{\#(?!\s*djlint\:\s*(?:on|off))
             | <pre
             | <textarea
             | {%[ ]*?blocktrans(?:late)?[^(?:%})]*?%}
@@ -486,22 +486,22 @@ class Config:
         )
         self.attribute_pattern: str = (
             r"""
-            (?:[^\s]+?=(?:\"[^\"]*?"""
+            (?:[^\s]+?[ ]*?=[ ]*?(?:\"[^\"]*?"""
             + self.template_if_for_pattern
             + r"""[^\"]*?\"|\'[^\']*?"""
             + self.template_if_for_pattern
             + r"""[^\']*?\'))
-            | (?:[^\s]+?=(?:\"[^\"]*?{{.*?}}[^\"]*?\"|\'[^\']*?{{.*?}}[^\']*?\'))
+            | (?:[^\s]+?[ ]*?=[ ]*?(?:\"[^\"]*?{{.*?}}[^\"]*?\"|\'[^\']*?{{.*?}}[^\']*?\'))
             | """
             + self.template_if_for_pattern
             + r"""
-            | (?:[^\s]+?=(?:\"(?:[^\"]*?{%[^}]*?%}[^\"]*?)+?\"))
-            | (?:[^\s]+?=(?:\'(?:[^\']*?{%[^}]*?%}[^\']*?)+?\'))
-            | (?:[^\s]+?=(?:\".*?\"|\'.*?\'))
+            | (?:[^\s]+?[ ]*?=[ ]*?(?:\"(?:[^\"]*?{%[^}]*?%}[^\"]*?)+?\"))
+            | (?:[^\s]+?[ ]*?=[ ]*?(?:\'(?:[^\']*?{%[^}]*?%}[^\']*?)+?\'))
+            | (?:[^\s]+?[ ]*?=[ ]*?(?:\".*?\"|\'.*?\'))
             | required
             | checked
             | (?:\w|-|\.)+
-            | (?:\w|-|\.)+=(?:\w|-)+
+            | (?:\w|-|\.)+[ ]*?=[ ]*?(?:\w|-)+
             | {{.*?}}
             | {%.*?%}
         """
